@@ -1138,6 +1138,8 @@ def get_files(search_path=False, **kwargs):
     include = obj.get_kwarg(['include'], [], (list, str), **kwargs)
     if isinstance(include, (str)):
         include = [include]
+        
+    show_index_count = obj.get_kwarg(['show_index_count', 'show count'], True, bool, **kwargs)
 
     # print(f"file.get_files.kwarg['extension']: ",obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
     extension_array = obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs)
@@ -1153,7 +1155,7 @@ def get_files(search_path=False, **kwargs):
     if threaded is True:
         # print(f"file.get_files - Using threads for indexing.")
         for path in search_path:
-            gft = GetFilesThreaded(path, recursive=recursive, data_include=data_include, exclude=exclude, include=include, extensions=extension_array,include_meta_data=include_meta_data)
+            gft = GetFilesThreaded(path, recursive=recursive, data_include=data_include, exclude=exclude, include=include, extensions=extension_array,include_meta_data=include_meta_data,show_index_count=show_index_count)
             return gft.master()
     # print(json.dumps(extension_array, indent=4))
     for path in search_path:
@@ -1190,6 +1192,8 @@ def get_files(search_path=False, **kwargs):
                         # fd['file_hash'] = generateFileHash(fd['file_path'])
                     # print(f"file found.")
                     file_array.append(file_data)
+                    if show_index_count is True:
+                        print(f"files indexed: {len(file_array)}",end="\r",flush=True)
                 # else:
                     # print(f"file_data is none")
             if recursive is False:
@@ -1200,7 +1204,8 @@ def get_files(search_path=False, **kwargs):
         # file_array = path_files + file_array
     if include_meta_data is True:
         file_array = _add_jpg_meta_data(file_array)
-    
+    if show_index_count is True:
+        print(f"Total Files Indexed: {len(file_array)}")
     return file_array
 
 def _add_jpg_meta_data(file_array):
@@ -1406,6 +1411,7 @@ class GetFilesThreaded:
             self.extension_array = [self.extension_array]
 
         self.include_meta_data = obj.get_kwarg(['image meta data', 'meta data','include meta data'], False, bool, **kwargs)
+        self.show_index_count = obj.get_kwarg(['show_index_count', 'show count'], True, bool, **kwargs)
 
 
     def remove_thread_by_id(self, thread_id):
@@ -1455,6 +1461,8 @@ class GetFilesThreaded:
                     return
 
         self.file_array.append(file_data)
+        if self.show_index_count is True:
+            print(f"files indexed: {len(self.file_array)}",end="\r",flush=True)
 
     def single_file_thread(self, data):
         '''
@@ -1507,6 +1515,8 @@ class GetFilesThreaded:
                 # print(f"Active Threads: {strUtils.format.left_pad(len(self.threads),3,'0')} Total Files: {len(self.file_array)}", end="\r", flush=True)
                 while len(self.threads) >= self.max_threads:
                     time.sleep(.1)
+                    
+                    
 
                 file_paths = [os.path.join(root, x) for x in files]
                 data = {
@@ -1528,6 +1538,8 @@ class GetFilesThreaded:
             thread.join()
         if self.include_meta_data is True:
             self.file_array = _add_jpg_meta_data(self.file_array)
+        if self.show_index_count is True:
+            print(f"Total Files Indexed: {len(self.file_array)}")
         return self.file_array
 
         # def _get_files_single_thread(search_path=False, recursive=False, exclude=None, include=None, extensions=None, data_include=None):
