@@ -613,8 +613,9 @@ def apply_synonyms(file_keys,synonyms):
 def auto_tag_by_folder_name(watch_path,**kwargs):
     print(f"auto_tag_by_folder_name")
     synonyms = obj.get_kwarg(['synonyms'],False,(bool,dict),**kwargs)
+    print(f"Indexing images in {watch_path}")
     all_files = f.get_files(watch_path, ext="images",include_meta_data=True)
-    print(f"watching {len(all_files)} files")
+    print(f"Watching {len(all_files)} files")
     # duration = 0
 
     while True:
